# TauLidarCamera

[![Documentation Status](https://readthedocs.org/projects/taulidarcamera/badge/?version=latest)](https://taulidarcamera.readthedocs.io/en/latest/?badge=latest)

Python API for the Onion Tau Lidar Camera

![Onion Tau Lidar Camera](https://github.com/OnionIoT/tau-lidar-camera/raw/master/docs/img/onion-tau-lidar-camera-00.png)

## Main Features

TauLidarCamera is the host-side API for building applications with the Tau LiDAR Camera.

* Connecting to the camera
* Configuring camera settings
* Retrieving frames from the camera. Frames can be:
  * Depth data
  * Greyscale image data
  * Light amplitude data

## Installation & Supported Versions

Install using pip on the command line:

```
python -m pip install TauLidarCamera
```

Supports Python 3.7+

## API Reference & Documentation on [ReadTheDocs](https://taulidarcamera.readthedocs.io/)

Documentation & API reference can be found online: https://taulidarcamera.readthedocs.io/

## [Troubleshooting](https://taulidarcamera.readthedocs.io/en/latest/troubleshooting.html)

In case you encounter any issues, check out the [Troubleshooting section in the documentation](https://taulidarcamera.readthedocs.io/en/latest/troubleshooting.html) for tips on resolving any issues you encounter!

## [Examples](https://github.com/OnionIoT/tau-lidar-camera/tree/master/examples)

Example programs using the Tau Lidar Camera and the TauLidarCamera Python module can be found in the [`examples` directory on GitHub](https://github.com/OnionIoT/tau-lidar-camera/tree/master/examples).

## Contributing to Development

See the [development document](https://github.com/OnionIoT/tau-lidar-camera/blob/master/DEVELOPMENT.md) for instructions on local development.

More info on contributing coming soon!
